@@ -36,11 +36,6 @@ class MergeVideoModelFaceRequest(RpcRequest):
 
 	def set_FaceImageURL(self, FaceImageURL):  # String
 		self.add_body_params('FaceImageURL', FaceImageURL)
-	def get_UserId(self): # String
-		return self.get_body_params().get('UserId')
-
-	def set_UserId(self, UserId):  # String
-		self.add_body_params('UserId', UserId)
 	def get_TemplateId(self): # String
 		return self.get_body_params().get('TemplateId')
 
